We compute the equation and nonminimal resolution F of the carpet of type (a,b) where $a \ge b$ over a larger finite prime field, lift the complex to the integers, which is possible since the coefficients are small. Finally we study the nonminimal strands over ZZ by computing the Smith normal form. The resulting data allow us to compute the Betti tables for arbitrary primes.
i1 : a=5,b=5
o1 = (5, 5)
o1 : Sequence
|
i2 : h=carpetBettiTables(a,b)
-- .00613544s elapsed
-- .0264667s elapsed
-- .0295362s elapsed
-- .0121114s elapsed
-- .00796721s elapsed
0 1 2 3 4 5 6 7 8 9
o2 = HashTable{0 => total: 1 36 160 315 288 288 315 160 36 1}
0: 1 . . . . . . . . .
1: . 36 160 315 288 . . . . .
2: . . . . . 288 315 160 36 .
3: . . . . . . . . . 1
0 1 2 3 4 5 6 7 8 9
2 => total: 1 36 167 370 476 476 370 167 36 1
0: 1 . . . . . . . . .
1: . 36 160 322 336 140 48 7 . .
2: . . 7 48 140 336 322 160 36 .
3: . . . . . . . . . 1
0 1 2 3 4 5 6 7 8 9
3 => total: 1 36 160 315 302 302 315 160 36 1
0: 1 . . . . . . . . .
1: . 36 160 315 288 14 . . . .
2: . . . . 14 288 315 160 36 .
3: . . . . . . . . . 1
o2 : HashTable
|
i3 : T= carpetBettiTable(h,3)
0 1 2 3 4 5 6 7 8 9
o3 = total: 1 36 160 315 302 302 315 160 36 1
0: 1 . . . . . . . . .
1: . 36 160 315 288 14 . . . .
2: . . . . 14 288 315 160 36 .
3: . . . . . . . . . 1
o3 : BettiTally
|
i4 : J=canonicalCarpet(a+b+1,b,Characteristic=>3);
ZZ
o4 : Ideal of --[x ..x , y ..y ]
3 0 5 0 5
|
i5 : elapsedTime T'=minimalBetti J
-- .227382s elapsed
0 1 2 3 4 5 6 7 8 9
o5 = total: 1 36 160 315 302 302 315 160 36 1
0: 1 . . . . . . . . .
1: . 36 160 315 288 14 . . . .
2: . . . . 14 288 315 160 36 .
3: . . . . . . . . . 1
o5 : BettiTally
|
i6 : T-T'
0 1 2 3 4 5 6 7 8 9
o6 = total: . . . . . . . . . .
1: . . . . . . . . . .
2: . . . . . . . . . .
3: . . . . . . . . . .
o6 : BettiTally
|
i7 : elapsedTime h=carpetBettiTables(6,6);
-- .0067094s elapsed
-- .110628s elapsed
-- .249961s elapsed
-- 1.67094s elapsed
-- .722966s elapsed
-- .0829238s elapsed
-- .00767177s elapsed
-- 7.92583s elapsed
|
i8 : keys h
o8 = {0, 2, 3, 5}
o8 : List
|
i9 : carpetBettiTable(h,7)
0 1 2 3 4 5 6 7 8 9 10 11
o9 = total: 1 55 320 891 1408 1155 1155 1408 891 320 55 1
0: 1 . . . . . . . . . . .
1: . 55 320 891 1408 1155 . . . . . .
2: . . . . . . 1155 1408 891 320 55 .
3: . . . . . . . . . . . 1
o9 : BettiTally
|
i10 : carpetBettiTable(h,5)
0 1 2 3 4 5 6 7 8 9 10 11
o10 = total: 1 55 320 891 1408 1275 1275 1408 891 320 55 1
0: 1 . . . . . . . . . . .
1: . 55 320 891 1408 1155 120 . . . . .
2: . . . . . 120 1155 1408 891 320 55 .
3: . . . . . . . . . . . 1
o10 : BettiTally
|